@@ -1,9 +1,10 @@
 import typing
 
-from django.conf import settings
 from django.http import HttpRequest
 from rest_framework.exceptions import NotAuthenticated, AuthenticationFailed
 
+from rest_framework_simple_api_key.settings import package_settings
+
 
 class APIKeyParser:
     """
@@ -11,14 +12,10 @@ class APIKeyParser:
     authorization header. You can add custom parsing validation here.
     """
 
-    keyword = settings.SIMPLE_API_KEY.get("AUTHENTICATION_KEYWORD_HEADER")
+    keyword = package_settings.AUTHENTICATION_KEYWORD_HEADER
     message = "No API key provided."
 
     def get(self, request: HttpRequest) -> typing.Optional[str]:
-        api_key_header = settings.SIMPLE_API_KEY.get("API_KEY_HEADER")
-
-        if api_key_header is not None:
-            return self.get_from_header(request, api_key_header)
 
         return self.get_from_authorization(request)
 
